@@ -11,6 +11,13 @@ from telescope_sdk.utils import (
 )
 
 
+@dataclass_json
+@dataclass
+class CanonicalJobTitle:
+    title: str
+    confidence: float
+
+
 @dataclass_json
 @dataclass
 class ExperienceCompany:
@@ -117,6 +124,7 @@ class Person(IngestedDataType):
     industry: Optional[str] = None
     company_id: Optional[str] = None
     job_title: Optional[str] = None
+    canonical_job_titles: Optional[CanonicalJobTitle] = None
     job_title_levels: Optional[list[str]] = None
     job_role_description: Optional[str] = None
     job_start_date: Optional[str] = None
@@ -167,6 +175,7 @@ class Person(IngestedDataType):
             industry=pdl_input.get('industry'),
             company_id=pdl_input.get('job_company_linkedin_id'),
             job_title=pdl_input.get('job_title'),
+            canonical_job_titles=None,
             job_title_levels=pdl_input.get('job_title_levels'),
             job_role_description=pdl_input.get('job_summary'),
             job_start_date=convert_date_string_to_datetime_string(job_start_date) if job_start_date else None,
